<?php
/**
 * Plugin Name:           GamiPress - Divi integration
 * Plugin URI:            https://wordpress.org/plugins/gamipress-divi-integration/
 * Description:           Connect GamiPress with Divi.
 * Version:               1.0.0
 * Author:                GamiPress
 * Author URI:            https://gamipress.com/
 * Text Domain:           gamipress-divi-integration
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.2
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               GamiPress\Divi
 * @author                GamiPress
 * @copyright             Copyright (c) GamiPress
 */

final class GamiPress_Divi {

    /**
     * @var         GamiPress_Divi $instance The one true GamiPress_Divi
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      GamiPress_Divi self::$instance The one true GamiPress_Divi
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new GamiPress_Divi();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'GAMIPRESS_DIVI_VER', '1.0.0' );

        // Plugin path
        define( 'GAMIPRESS_DIVI_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'GAMIPRESS_DIVI_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            require_once GAMIPRESS_DIVI_DIR . 'includes/admin.php';
            require_once GAMIPRESS_DIVI_DIR . 'includes/listeners.php';
            require_once GAMIPRESS_DIVI_DIR . 'includes/requirements.php';
            require_once GAMIPRESS_DIVI_DIR . 'includes/rules-engine.php';
            require_once GAMIPRESS_DIVI_DIR . 'includes/scripts.php';
            require_once GAMIPRESS_DIVI_DIR . 'includes/triggers.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {
        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'GAMIPRESS_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'GamiPress - Divi integration requires %s and %s in order to work. Please install and activate them.', 'gamipress-divi-integration' ),
                        '<a href="https://wordpress.org/plugins/gamipress/" target="_blank">GamiPress</a>',
                        '<a href="hhttps://www.elegantthemes.com/gallery/divi/" target="_blank">Divi Theme</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'GAMIPRESS_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'GamiPress' ) ) {
            return false;
        }

        $theme = wp_get_theme();

        if ( $theme->get_template() !== 'Divi' ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = GAMIPRESS_DIVI_DIR . '/languages/';
        $lang_dir = apply_filters( 'gamipress_divi_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'gamipress-divi-integration' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'gamipress-divi-integration', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/gamipress-divi-integration/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/gamipress-divi-integration/ folder
            load_textdomain( 'gamipress-divi-integration', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/gamipress-divi-integration/languages/ folder
            load_textdomain( 'gamipress-divi-integration', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'gamipress-divi-integration', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true GamiPress_Divi instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \GamiPress_Divi The one true GamiPress_Divi
 */
function GamiPress_Divi() {
    return GamiPress_Divi::instance();
}
add_action( 'plugins_loaded', 'GamiPress_Divi' );
